==> bcc-core-api-node-sdk-1.7.0.tgz: package/lib/esm/test/helpers.js <==
import { CoreApiClient } from "../api";
import { Environment } from "../model/environment";
export function getDefaultConfig() {
    return {
        environment: Environment.Emulator,
        clientId: "0000",
        clientSecret: "0000"
    };
}
export const client = new CoreApiClient(getDefaultConfig());
export const oldExpiredToken = "eyJraWQiOiI2YmIwYzhkYzQyYWIxODM4MzZjMWVkM2NiNjJiMzY2MWYwMzNjMzMyNmNlZjY0NjYzNWY0MWI2NTE0ZTFiZjVmOGQ5OGEwMmE2OWViY2E3ZiIsInR5cCI6IkpXVCIsImFsZyI6IlJTMjU2In0.eyJpc3MiOiJodHRwOi8vbG9jYWxob3N0OjIwMzAiLCJpYXQiOjE2Nzc4NTgyMDcsImV4cCI6MTY3Nzg2MTgwNywibmJmIjoxNjc3ODU4MTk3LCJzY29wZSI6InBlcnNvbnMjcmVhZCBvcmdzI3JlYWQiLCJzdWIiOiIwMDAwIiwiYXpwIjoiMDAwMCIsImF1ZCI6ImxvY2FsaG9zdDoyMDMwIiwiZ3R5IjoiY2xpZW50LWNyZWRlbnRpYWxzIn0.UxdJ3vIlJxnk1kjvUFlVKPg4dG61MSUp9roXCZe9QNwYm3ET5FecNmG36kU63D3e8rlY1dnf3NRgChgFwIn3P6C745U024ILUNrdaJk5P20yED-3pqv8BIV04E32nVxH8XCXU2V3ooulBoczn1mFURmfx3fTcn4EBxt98-Y5vvS8CBcuFX7VAcStY4HJxobK_Oj4rX-hDEYWlxFyqCl40r2COIrpyZM8p7-VyJb7xaJCz5Lv9qs85q3Isuz3ugZs-pi2sszTNxRG2ktjNsuBv3WRkZLYA5xefjKNoymKAi5GqjUnZb35tYqQssdtLTLZsjKzife2KeO8Pj3W3Q8qGg";
export const basicRequest = {
    url: "",
    headers: {},
};
export const affiliationUid = "8c743b8c-751b-4a76-b48d-92823cd3c44a";
export const org1Uid = "9e0b8d03-9799-416d-a70b-6da9f2e1ab48";
export const person1Uid = "657a66ca-9cd0-4b61-9476-697016e26fbc";
export const person1ActiveConsentUid = "f3542616-bed9-4f46-a559-41356889d407";
export const countryUid = "18ffbac2-8d17-41b2-a1d7-3f46382e169b";
export const relationUid = "3a0c7609-bd9e-4f1e-a5b2-e8471ebc7b92";
export function delay(time) {
    return new Promise(resolve => setTimeout(resolve, time));
}

==> bcc-core-api-node-sdk-1.7.2.tgz: package/lib/esm/test/helpers.js <==
import { CoreApiClient, Environment } from "../api";
export function getDefaultConfig() {
    return {
        environment: Environment.Emulator,
        clientId: "0000",
        clientSecret: "0000",
    };
}
export const client = new CoreApiClient(getDefaultConfig());
export const oldExpiredToken = "eyJraWQiOiI2YmIwYzhkYzQyYWIxODM4MzZjMWVkM2NiNjJiMzY2MWYwMzNjMzMyNmNlZjY0NjYzNWY0MWI2NTE0ZTFiZjVmOGQ5OGEwMmE2OWViY2E3ZiIsInR5cCI6IkpXVCIsImFsZyI6IlJTMjU2In0.eyJpc3MiOiJodHRwOi8vbG9jYWxob3N0OjIwMzAiLCJpYXQiOjE2Nzc4NTgyMDcsImV4cCI6MTY3Nzg2MTgwNywibmJmIjoxNjc3ODU4MTk3LCJzY29wZSI6InBlcnNvbnMjcmVhZCBvcmdzI3JlYWQiLCJzdWIiOiIwMDAwIiwiYXpwIjoiMDAwMCIsImF1ZCI6ImxvY2FsaG9zdDoyMDMwIiwiZ3R5IjoiY2xpZW50LWNyZWRlbnRpYWxzIn0.UxdJ3vIlJxnk1kjvUFlVKPg4dG61MSUp9roXCZe9QNwYm3ET5FecNmG36kU63D3e8rlY1dnf3NRgChgFwIn3P6C745U024ILUNrdaJk5P20yED-3pqv8BIV04E32nVxH8XCXU2V3ooulBoczn1mFURmfx3fTcn4EBxt98-Y5vvS8CBcuFX7VAcStY4HJxobK_Oj4rX-hDEYWlxFyqCl40r2COIrpyZM8p7-VyJb7xaJCz5Lv9qs85q3Isuz3ugZs-pi2sszTNxRG2ktjNsuBv3WRkZLYA5xefjKNoymKAi5GqjUnZb35tYqQssdtLTLZsjKzife2KeO8Pj3W3Q8qGg";
export const basicRequest = {
    url: "",
    headers: {},
};
export const affiliationUid = "8c743b8c-751b-4a76-b48d-92823cd3c44a";
export const org1Uid = "9e0b8d03-9799-416d-a70b-6da9f2e1ab48";
export const person1Uid = "657a66ca-9cd0-4b61-9476-697016e26fbc";
export const person1ActiveConsentUid = "f3542616-bed9-4f46-a559-41356889d407";
export const countryUid = "18ffbac2-8d17-41b2-a1d7-3f46382e169b";
export const relationUid = "3a0c7609-bd9e-4f1e-a5b2-e8471ebc7b92";
export function delay(time) {
    return new Promise((resolve) => setTimeout(resolve, time));
}
